@@ -75,7 +75,7 @@ class ExportDataSet(CustomExport):
         return "ExportedDataSet.xlsx"
 
     def get_custom_export_data(self, data_set):
-        return threadlocal.get_current_request().app.export_data_set(request.data_set)
+        return threadlocal.get_current_request().app.get_data_set_as_excel_wb_string_repr(data_set)
     
     def get_export_button_text(self):
         return 'Export Data Set'
