@@ -62,7 +62,10 @@ class DataSets(Widget):
             export_data_set_form.actions('refresh'),
         ]
 
-        manage_ds_form.add_event_subscription('formSubmitSuccess', refresh_actions_on_data_set_changes)
+        manage_ds_form.add_event_subscription('formSubmitSuccess', [  # Exclude manage_ds_form - manually refreshed in js.
+            open_data_set_form.actions('refresh'),
+            export_data_set_form.actions('refresh'),
+        ])
         import_new_ds_upload_widget.add_event_subscription('fileUploadSuccess', refresh_actions_on_data_set_changes)
         import_ds_name_edit.add_event_subscription('formSubmitSuccess', refresh_actions_on_data_set_changes)
 
